@@ -1,6 +1,6 @@
 <?php
   /**
-   **  Email Footer (email_footer) v0.3.0
+   **  Email Footer (email_footer) v0.4.0
    **
    **  By Ray Black III <allah@accessnode.net>
    **  Changes By Paul Lesneiwski <pdontthink@angryners.com>
@@ -29,19 +29,21 @@ function squirrelmail_plugin_init_email_footer()
 function email_footer_version()
 {
 
-   return '0.3';
+   return '0.4';
 
 }
 
 
+
+if (!defined('SM_PATH'))
+   define('SM_PATH', '../');
+
+
+
 function email_footer_addition(&$argv)
 {
 
-    if (defined('SM_PATH'))
-       include_once(SM_PATH . 'plugins/email_footer/functions.php');
-    else
-       include_once('../plugins/email_footer/functions.php');
-
+    include_once(SM_PATH . 'plugins/email_footer/functions.php');
     return email_footer_addition_do($argv);
 
 }
@@ -50,11 +52,7 @@ function email_footer_addition(&$argv)
 function email_footer_subtraction()
 {  
      
-    if (defined('SM_PATH'))
-       include_once(SM_PATH . 'plugins/email_footer/functions.php');
-    else
-       include_once('../plugins/email_footer/functions.php');
-
+    include_once(SM_PATH . 'plugins/email_footer/functions.php');
     email_footer_subtraction_do();
         
 }
